summaryrefslogtreecommitdiffstats
path: root/kmail/headerlistquicksearch.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headerlistquicksearch.h')
-rw-r--r--kmail/headerlistquicksearch.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/headerlistquicksearch.h b/kmail/headerlistquicksearch.h
index e0589c7d6..0e3c4c9de 100644
--- a/kmail/headerlistquicksearch.h
+++ b/kmail/headerlistquicksearch.h
@@ -31,7 +31,7 @@
#ifndef KMAILHEADERLISTQUICKSEARCH_H
#define KMAILHEADERLISTQUICKSEARCH_H
-#include "kmmsgbase.h" // for KMMsgtqStatus
+#include "kmmsgbase.h" // for KMMsgStatus
#include "kmsearchpattern.h"
#include <klistviewsearchline.h>
#include <tqvaluevector.h>
@@ -67,7 +67,7 @@ public:
/**
* Returns the currently selected status filter.
*/
- int currentqStatus() const;
+ int currenStatus() const;
public slots:
void reset();
@@ -78,22 +78,22 @@ signals:
protected:
/**
* checks whether @param item contains the search string and has the status
* currently in mtqStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
private slots:
/**
* cache the status in mtqStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/
void sloStatusChanged( int index );
private:
/** Helper method for the filling of the status combo. */
- void insertqStatus(KMail::StatusValueTypes which);
+ void inserStatus(KMail::StatusValueTypes which);
TQComboBox *mStatusCombo;
- KMMsgtqStatus mtqStatus;
+ KMMsgStatus mStatus;
TQValueVector<TQString> statusList;
mutable TQString mCurrentSearchTerm;
};
@@ -78,22 +78,22 @@ signals:
/**
* checks whether @param item contains the search string and has the status
- * currently in mtqStatus
+ * currently in mStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
@@ -78,22 +78,22 @@ signals:
private slots:
/**
- * cache the status in mtqStatus so as to avoid having to do the comparatively
+ * cache the status in mStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/